@@ -1,7 +1,9 @@
+from datetime import date
 import itertools
 import numpy as np
 import pytest
 import sys
+import xml.etree.ElementTree
 
 import tiledb
 from tiledb.main import PyFragmentInfo
@@ -37,39 +39,36 @@ class FragmentInfoTest(DiskTestCase):
             with tiledb.DenseArray(uri, mode="w", timestamp=timestamp) as T:
                 T[fragment_idx : fragment_idx + 1] = fragment_idx
 
-        fragments_info = tiledb.array_fragments(uri)
+        fi = tiledb.array_fragments(uri)
 
-        self.assertEqual(len(fragments_info), 3)
-        self.assertEqual(fragments_info.unconsolidated_metadata_num, 3)
+        assert len(fi) == 3
+        assert fi.unconsolidated_metadata_num == 3
+        assert fi.cell_num == (3, 3, 3)
+        assert fi.has_consolidated_metadata == (False, False, False)
+        assert fi.nonempty_domain == (((0, 0),), ((1, 1),), ((2, 2),))
+        assert fi.sparse == (False, False, False)
+        assert fi.timestamp_range == ((1, 1), (2, 2), (3, 3))
+        assert fi.to_vacuum == ()
+        assert hasattr(fi, "version")  # don't pin to a specific version
 
-        self.assertEqual(fragments_info.cell_num, (3, 3, 3))
-        self.assertEqual(
-            fragments_info.has_consolidated_metadata, (False, False, False)
-        )
-        self.assertEqual(
-            fragments_info.nonempty_domain, (((0, 0),), ((1, 1),), ((2, 2),))
-        )
-        self.assertEqual(fragments_info.sparse, (False, False, False))
-        self.assertEqual(fragments_info.timestamp_range, ((1, 1), (2, 2), (3, 3)))
-        self.assertEqual(fragments_info.to_vacuum, ())
+        for idx, frag in enumerate(fi):
+            assert frag.cell_num == 3
+            assert frag.has_consolidated_metadata == False
+            assert frag.nonempty_domain == ((idx, idx),)
+            assert frag.sparse == False
+            assert frag.timestamp_range == (idx + 1, idx + 1)
+            assert hasattr(frag, "version")  # don't pin to a specific version
+            try:
+                assert xml.etree.ElementTree.fromstring(frag._repr_html_()) is not None
+            except:
+                pytest.fail(
+                    f"Could not parse frag._repr_html_(). Saw {frag._repr_html_()}"
+                )
 
-        for idx, frag in enumerate(fragments_info):
-            self.assertEqual(frag.cell_num, 3)
-            self.assertEqual(frag.has_consolidated_metadata, False)
-            self.assertEqual(frag.nonempty_domain, ((idx, idx),))
-            self.assertEqual(frag.sparse, False)
-            self.assertEqual(frag.timestamp_range, (idx + 1, idx + 1))
-
-            if tiledb.libtiledb.version() < (2, 2, 3):
-                assert frag.version == 7
-            elif tiledb.libtiledb.version() < (2, 3, 0):
-                assert frag.version == 8
-            else:
-                # make sure the version is within some reasonable bound
-                # but don't pin because that makes testing against dev
-                # more difficult
-                assert frag.version >= 9
-                assert frag.version < 12
+        try:
+            assert xml.etree.ElementTree.fromstring(fi._repr_html_()) is not None
+        except:
+            pytest.fail(f"Could not parse fi._repr_html_(). Saw {fi._repr_html_()}")
 
     def test_array_fragments_var(self):
         fragments = 3
@@ -161,16 +160,6 @@ class FragmentInfoTest(DiskTestCase):
 
         self.assertEqual(fragment_info.get_timestamp_range(), ((1, 1), (2, 2), (3, 3)))
         self.assertEqual(fragment_info.get_sparse(), (False, False, False))
-        if tiledb.libtiledb.version() < (2, 2, 3):
-            assert fragment_info.get_version()[0] == 7
-        elif tiledb.libtiledb.version() < (2, 3, 0):
-            assert fragment_info.get_version()[0] == 8
-        else:
-            # make sure the version is within some reasonable bound
-            # but don't pin because that makes testing against dev
-            # more difficult
-            assert fragment_info.get_version()[0] >= 9
-            assert fragment_info.get_version()[0] < 12
 
     def test_sparse_fragments(self):
         fragments = 3
@@ -224,16 +213,6 @@ class FragmentInfoTest(DiskTestCase):
 
         self.assertEqual(fragment_info.get_timestamp_range(), ((1, 1), (2, 2), (3, 3)))
         self.assertEqual(fragment_info.get_sparse(), (True, True, True))
-        if tiledb.libtiledb.version() < (2, 2, 3):
-            assert fragment_info.get_version()[0] == 7
-        elif tiledb.libtiledb.version() < (2, 3, 0):
-            assert fragment_info.get_version()[0] == 8
-        else:
-            # make sure the version is within some reasonable bound
-            # but don't pin because that makes testing against dev
-            # more difficult
-            assert fragment_info.get_version()[0] >= 9
-            assert fragment_info.get_version()[0] < 12
 
     def test_nonempty_domain(self):
         uri = self.path("test_nonempty_domain")
@@ -424,7 +403,10 @@ class FragmentInfoTest(DiskTestCase):
 
     @pytest.mark.skipif(
         tiledb.libtiledb.version() < (2, 5, 0),
-        reason="MBRs in FragmentInfo only availabe in ilbtiledb<=2.5.0",
+        reason=(
+            "MBRs in FragmentInfo only available in "
+            "tiledb.libtiledb.version() < (2, 5, 0)"
+        ),
     )
     def test_get_mbr(self):
         fragments = 3
@@ -464,6 +446,52 @@ class FragmentInfoTest(DiskTestCase):
         assert array_fragments[1].mbrs == expected_mbrs[1]
         assert array_fragments[2].mbrs == expected_mbrs[2]
 
+    @pytest.mark.skipif(
+        tiledb.libtiledb.version() < (2, 5, 0),
+        reason=(
+            "MBRs in FragmentInfo only available in "
+            "tiledb.libtiledb.version() < (2, 5, 0)"
+        ),
+    )
+    def test_get_var_sized_dim_mbrs(self):
+        fragments = 3
+
+        uri = self.path("test_get_var_sized_dim_mbrs")
+        dom = tiledb.Domain(tiledb.Dim(dtype="ascii"))
+        att = tiledb.Attr(dtype=np.uint64)
+        schema = tiledb.ArraySchema(domain=dom, attrs=(att,), sparse=True)
+        tiledb.Array.create(uri, schema)
+
+        for fragi in range(fragments):
+            timestamp = fragi + 1
+            with tiledb.open(uri, mode="w", timestamp=timestamp) as T:
+                coords = [chr(i) * (fragi + 1) for i in range(97, fragi + 98)]
+                T[np.array(coords)] = [fragi] * (fragi + 1)
+
+        expected_mbrs = (((("a", "a"),),), ((("aa", "bb"),),), ((("aaa", "ccc"),),))
+
+        py_fragment_info = PyFragmentInfo(uri, schema, True, tiledb.default_ctx())
+        assert py_fragment_info.get_mbrs() == expected_mbrs
+
+        array_fragments = tiledb.array_fragments(uri)
+        with pytest.raises(AttributeError) as excinfo:
+            array_fragments.mbrs
+        assert "retrieving minimum bounding rectangles is disabled" in str(
+            excinfo.value
+        )
+
+        with self.assertRaises(AttributeError):
+            array_fragments[0].mbrs
+        assert "retrieving minimum bounding rectangles is disabled" in str(
+            excinfo.value
+        )
+
+        array_fragments = tiledb.array_fragments(uri, include_mbrs=True)
+        assert array_fragments.mbrs == expected_mbrs
+        assert array_fragments[0].mbrs == expected_mbrs[0]
+        assert array_fragments[1].mbrs == expected_mbrs[1]
+        assert array_fragments[2].mbrs == expected_mbrs[2]
+
 
 class CreateArrayFromFragmentsTest(DiskTestCase):
     @pytest.mark.skipif(
@@ -653,6 +681,9 @@ class DeleteFragmentsTest(DiskTestCase):
         with tiledb.open(path, "w", timestamp=2) as A:
             A[[1, 2, 3]] = {"a1": ts2_data, "a2": ts2_data}
 
+        frags = tiledb.array_fragments(path)
+        assert len(frags) == 2
+
         with tiledb.open(path, "r") as A:
             assert A.schema.has_attr("a1")
             assert A.schema.has_attr("a2")
@@ -661,6 +692,9 @@ class DeleteFragmentsTest(DiskTestCase):
 
         tiledb.delete_fragments(path, (2, 2))
 
+        frags = tiledb.array_fragments(path)
+        assert len(frags) == 1
+
         with tiledb.open(path, "r") as A:
             assert A.schema.has_attr("a1")
             assert not A.schema.has_attr("a2")
