@@ -123,8 +123,18 @@ class TestColumnInfo:
         "type_specs, info_dtype, info_repr, info_nullable",
         [
             # bool types
-            ([bool, "b1"], np.dtype("uint8"), "bool", False),
-            ([pd.BooleanDtype()], np.dtype("uint8"), "boolean", True),
+            (
+                [bool, "b1"],
+                np.dtype("uint8" if tiledb.libtiledb.version() < (2, 10) else "bool"),
+                "bool",
+                False,
+            ),
+            (
+                [pd.BooleanDtype()],
+                np.dtype("uint8" if tiledb.libtiledb.version() < (2, 10) else "bool"),
+                "boolean",
+                True,
+            ),
             # numeric types
             ([np.uint8, "u1"], np.dtype("uint8"), None, False),
             ([np.uint16, "u2"], np.dtype("uint16"), None, False),
@@ -239,6 +249,7 @@ class TestDimType:
         with tiledb.open(uri) as A:
             assert A.schema.domain.dim(0).dtype == expected
             assert A.schema.domain.dim(0).name == df.index.name
+            assert A.schema.domain.dim(0).filters == [tiledb.ZstdFilter()]
 
 
 class TestPandasDataFrameRoundtrip(DiskTestCase):
@@ -309,9 +320,13 @@ class TestPandasDataFrameRoundtrip(DiskTestCase):
         tiledb.from_pandas(uri, df, full_domain=True, sparse=False)
 
         with tiledb.open(uri) as A:
-            dim = A.schema.domain.dim(0)
+            dim = A.domain.dim(0)
             assert dim.domain[0] == dtype_min(np.int64)
             assert dim.domain[1] == dtype_max(np.int64) - dim.tile
+            assert dim.filters == [tiledb.ZstdFilter()]
+
+            attr = A.attr(0)
+            assert attr.filters == [tiledb.ZstdFilter()]
 
         for use_arrow in None, False, True:
             df_readback = tiledb.open_dataframe(uri, use_arrow=use_arrow)
@@ -566,7 +581,7 @@ class TestPandasDataFrameRoundtrip(DiskTestCase):
                 with tiledb.open(uri) as A:
                     tm.assert_frame_equal(df.iloc[:0], A.df[tiledb.EmptyRange])
 
-    @pytest.mark.skip(
+    @pytest.mark.skipif(
         tiledb.libtiledb.version() < (2, 4, 3),
         reason="Skip this test to avoid abort: requires TileDB#2540 in TileDB 2.4.3",
     )
@@ -623,6 +638,11 @@ class TestPandasDataFrameRoundtrip(DiskTestCase):
             df.to_csv(fio)
 
         tmp_array = os.path.join(tmp_dir, "array")
+
+        with self.assertRaisesRegex(ValueError, "expected a TileDB Context object"):
+            cfg = tiledb.Config()
+            tiledb.from_csv(tmp_array, tmp_csv, ctx=cfg)
+
         tiledb.from_csv(
             tmp_array,
             tmp_csv,
@@ -732,59 +752,70 @@ class TestPandasDataFrameRoundtrip(DiskTestCase):
             tiledb.from_csv(tmp_assert_dir, tmp_csv, tile=(3, 1.0))
 
         tmp_array = os.path.join(tmp_dir, "array")
-        tiledb.from_csv(
-            tmp_array,
-            tmp_csv,
-            index_col=["time", "double_range"],
-            parse_dates=["time"],
-            mode="schema_only",
-            capacity=1001,
-            sparse=True,
-            tile={"time": 5},
-            coords_filters=coords_filters,
-            attr_filters=attrs_filters,
-        )
+        with pytest.warns(
+            DeprecationWarning,
+            match="coords_filters is deprecated; set the FilterList for each dimension",
+        ):
+            tiledb.from_csv(
+                tmp_array,
+                tmp_csv,
+                index_col=["time", "double_range"],
+                parse_dates=["time"],
+                mode="schema_only",
+                capacity=1001,
+                sparse=True,
+                tile={"time": 5},
+                coords_filters=coords_filters,
+                attr_filters=attrs_filters,
+            )
 
         t0, t1 = df.time.min(), df.time.max()
 
         import numpy
 
-        ref_schema = tiledb.ArraySchema(
-            domain=tiledb.Domain(
-                *[
-                    tiledb.Dim(
-                        name="time",
-                        domain=(t0.to_datetime64(), t1.to_datetime64()),
-                        tile=5,
-                        dtype="datetime64[ns]",
-                    ),
-                    tiledb.Dim(
-                        name="double_range",
-                        domain=(-1000.0, 1000.0),
-                        tile=1000,
-                        dtype="float64",
-                    ),
-                ]
-            ),
-            attrs=[tiledb.Attr(name="int_vals", dtype="int64", filters=attrs_filters)],
-            coords_filters=coords_filters,
-            cell_order="row-major",
-            tile_order="row-major",
-            capacity=1001,
-            sparse=True,
-            allows_duplicates=False,
-        )
-        # note: filters omitted
+        with pytest.warns(
+            DeprecationWarning,
+            match="coords_filters is deprecated; set the FilterList for each dimension",
+        ):
+            ref_schema = tiledb.ArraySchema(
+                domain=tiledb.Domain(
+                    *[
+                        tiledb.Dim(
+                            name="time",
+                            domain=(t0.to_datetime64(), t1.to_datetime64()),
+                            tile=5,
+                            dtype="datetime64[ns]",
+                        ),
+                        tiledb.Dim(
+                            name="double_range",
+                            domain=(-1000.0, 1000.0),
+                            tile=1000,
+                            dtype="float64",
+                        ),
+                    ]
+                ),
+                attrs=[
+                    tiledb.Attr(name="int_vals", dtype="int64", filters=attrs_filters)
+                ],
+                coords_filters=coords_filters,
+                cell_order="row-major",
+                tile_order="row-major",
+                capacity=1001,
+                sparse=True,
+                allows_duplicates=False,
+            )
+            # note: filters omitted
 
-        array_nfiles = len(tiledb.VFS().ls(tmp_array))
-        self.assertEqual(array_nfiles, 3 if tiledb.libtiledb.version() < (2, 7) else 2)
+        fi = tiledb.array_fragments(tmp_array)
+        assert len(fi) == 0
 
         with tiledb.open(tmp_array) as A:
             self.assertEqual(A.schema, ref_schema)
-
-            # TODO currently no equality check for filters
-            self.assertEqual(A.schema.coords_filters[0].level, coords_filters[0].level)
-            self.assertEqual(A.schema.attr(0).filters[0].level, attrs_filters[0].level)
+            assert A.dim(0).filters[0] == tiledb.ZstdFilter(level=7)
+            assert A.dim(1).filters[0] == tiledb.ZstdFilter(level=7)
+            assert len(A.schema.coords_filters) == 0
+            assert A.attr(0).filters[0] == attrs_filters[0]
+            assert A.attr(0).filters[0].level == attrs_filters[0].level
 
         # Test mode='append' for from_csv
         tiledb.from_csv(tmp_array, tmp_csv, mode="append", row_start_idx=0)
@@ -968,10 +999,17 @@ class TestPandasDataFrameRoundtrip(DiskTestCase):
         )
 
         # Check number of fragments
-        # * should equal 8 based on chunksize=25
-        # * 20 files, 10 rows each, 200 rows == 8 writes:
-        fragments = glob.glob(tmp_array + "/*.ok")
-        self.assertEqual(len(fragments), 8)
+        frags_dir = os.path.join(tmp_array, "__fragments")
+        if self.vfs.is_dir(frags_dir):
+            fragments = self.vfs.ls(frags_dir)
+        else:
+            fragments = glob.glob(tmp_array + "/*.ok")
+        assert len(fragments) == 8
+
+        # TODO: THIS IS ERRORING OUT; prefer this to above
+        # https://app.shortcut.com/tiledb-inc/story/15277/fragmentinfo-overflowerror-int-too-big-to-convert
+        # fi = tiledb.array_fragments(tmp_array)
+        # assert len(fi) == 8
 
         # Check the returned data
         # note: tiledb returns sorted values
@@ -987,6 +1025,11 @@ class TestPandasDataFrameRoundtrip(DiskTestCase):
     def test_dataframe_misc(self):
         uri = self.path("test_small_domain_range")
         df = pd.DataFrame({"data": [2]}, index=[0])
+
+        with self.assertRaisesRegex(ValueError, "expected a TileDB Context object"):
+            cfg = tiledb.Config()
+            tiledb.from_pandas(uri, df, ctx=cfg)
+
         tiledb.from_pandas(uri, df)
 
         data = {
@@ -1020,9 +1063,11 @@ class TestPandasDataFrameRoundtrip(DiskTestCase):
         )
         with tiledb.open(uri) as A:
             self.assertTrue(A.schema.attr("data").filters == bz_filter)
-            self.assertTrue(A.schema.attr("raw").filters == tiledb.FilterList())
+            self.assertTrue(A.schema.attr("raw").filters == [tiledb.ZstdFilter()])
             self.assertTrue(A.schema.domain.dim("index").filters == bz_filter)
-            self.assertTrue(A.schema.domain.dim("indey").filters == tiledb.FilterList())
+            self.assertTrue(
+                A.schema.domain.dim("indey").filters == [tiledb.ZstdFilter()]
+            )
 
     def test_dataframe_query(self):
         uri = self.path("df_query")
@@ -1273,6 +1318,87 @@ class TestPandasDataFrameRoundtrip(DiskTestCase):
         with tiledb.open(uri, "r") as A:
             tm.assert_frame_equal(df, A.df[:])
 
+    @pytest.mark.parametrize("tile_order", ["row-major", "col-major"])
+    @pytest.mark.parametrize("cell_order", ["row-major", "col-major", "hilbert"])
+    def test_tile_and_cell_order(self, tile_order, cell_order):
+        uri_from_pandas = self.path("dataframe_basic_rt1_from_pandas")
+        df = make_dataframe_basic1()
+        tiledb.from_pandas(
+            uri_from_pandas,
+            df,
+            sparse=True,
+            tile_order=tile_order,
+            cell_order=cell_order,
+        )
+        with tiledb.open(uri_from_pandas) as A:
+            tm.assert_frame_equal(df, A.df[:])
+            column_types = {A.attr(i).name: A.attr(i).dtype for i in range(A.nattr)}
+
+        uri_from_csv = self.path("dataframe_basic_rt1_from_csv")
+        csv = self.path("csv_basic_rt1")
+        with self.vfs.open(csv, "wb") as fio:
+            df_convert = df.copy()
+            df_convert["x"] = df_convert["x"].str.decode("UTF-8")
+            df_convert["chars"] = df_convert["chars"].str.decode("UTF-8")
+            df_convert["r"] = df_convert["r"].str.decode("UTF-8")
+            df_convert["v"] = df_convert["v"].str.decode("UTF-8")
+            df_convert.to_csv(fio, index=False)
+        tiledb.from_csv(
+            uri_from_csv,
+            csv,
+            sparse=True,
+            tile_order=tile_order,
+            cell_order=cell_order,
+            column_types=column_types,
+            na_filter=False,  # https://github.com/TileDB-Inc/TileDB-Py/issues/1306#issuecomment-1233570928
+        )
+        with tiledb.open(uri_from_csv) as A:
+            tm.assert_frame_equal(df, A.df[:])
+
+    def test_set_ascii_dtype(self):
+        df = make_dataframe_basic1()
+
+        uri_char = self.path("test_set_ascii_dtype_char")
+        tiledb.from_pandas(uri_char, df, sparse=True)
+        with tiledb.open(uri_char) as A:
+            assert A.attr("x").dtype == np.dtype("S")
+            assert not A.attr("x").isascii
+
+        uri_ascii = self.path("test_set_ascii_dtype_ascii")
+        tiledb.from_pandas(uri_ascii, df, sparse=True, column_types={"x": "ascii"})
+        with tiledb.open(uri_ascii) as A:
+            assert A.attr("x").dtype == np.dtype("S")
+            assert A.attr("x").isascii
+
+    def test_append_empty_dataframe(self):
+        uri = self.path("test_append_empty_dataframe")
+        tiledb.from_pandas(
+            uri,
+            pd.DataFrame(index=["a", "b"]),
+            mode="ingest",
+        )
+        tiledb.from_pandas(
+            uri,
+            pd.DataFrame(index=pd.Index(data=[])),
+            mode="append",
+        )
+
+    def test_bool_type(self):
+        uri = self.path("test_bool_type")
+        df = pd.DataFrame.from_dict(
+            {
+                "obs_id": np.asarray(["ACTG", "GCTA"]),
+                "var_id": np.asarray(["ENS001", "ENS002"]),
+                "flags": np.asarray([True, False]),
+            }
+        )
+        df.set_index(["obs_id", "var_id"], inplace=True)
+        tiledb.from_pandas(uri, df)
+
+        with tiledb.open(uri) as A:
+            dtype = np.uint8 if tiledb.libtiledb.version() < (2, 10) else bool
+            assert A.schema.attr("flags").dtype == dtype
+
 
 class TestFromPandasOptions(DiskTestCase):
     def test_filters_options(self):
@@ -1335,9 +1461,21 @@ class TestFromPandasOptions(DiskTestCase):
                     continue
 
                 uri = self.path()
-                tiledb.from_pandas(uri, df, **{opt: f})
-                with tiledb.open(uri) as A:
-                    assert_filters_eq(getter(A), f)
+
+                if opt == "coords_filters":
+                    with pytest.warns(
+                        DeprecationWarning,
+                        match="coords_filters is deprecated; set the FilterList for each dimension",
+                    ):
+                        tiledb.from_pandas(uri, df, **{opt: f})
+
+                    with tiledb.open(uri) as A:
+                        assert len(A.schema.coords_filters) == 0
+                        assert_filters_eq(A.schema.domain.dim(0).filters, f)
+                else:
+                    tiledb.from_pandas(uri, df, **{opt: f})
+                    with tiledb.open(uri) as A:
+                        assert_filters_eq(getter(A), f)
 
 
 ###############################################################################
